@@ -1,6 +1,6 @@
 package Bio::MUST::Core::Types;
 # ABSTRACT: Distribution-wide Moose types for Bio::MUST::Core
-$Bio::MUST::Core::Types::VERSION = '0.210230';
+$Bio::MUST::Core::Types::VERSION = '0.210380';
 use Moose::Util::TypeConstraints;
 
 use autodie;
@@ -140,16 +140,15 @@ coerce 'Bio::MUST::Core::IdList'
     => from 'ArrayRef[Str]'
     => via { Bio::MUST::Core::IdList->new( ids => $_ ) }
 
-# TODO: uncomment and check this (still useful?)
-#     => from 'ArrayRef[Bio::MUST::Core::SeqId]'
-#     => via { Bio::MUST::Core::IdList->new(
-#         ids => [ map { $_->full_id } @{$_} ]
-#     ) }
-#
-#     => from 'ArrayRef[Bio::MUST::Core::Seq]'
-#     => via { Bio::MUST::Core::IdList->new(
-#         ids => [ map { $_->full_id } @{$_} ]
-#     ) }
+    => from 'ArrayRef[Bio::MUST::Core::SeqId]'
+    => via { Bio::MUST::Core::IdList->new(
+        ids => [ map { $_->full_id } @{$_} ]
+    ) }
+
+    => from 'ArrayRef[Bio::MUST::Core::Seq]'
+    => via { Bio::MUST::Core::IdList->new(
+        ids => [ map { $_->full_id } @{$_} ]
+    ) }
 
     => from 'Path::Class::File'
     => via { Bio::MUST::Core::IdList->load( $_->stringify ) }
@@ -221,7 +220,7 @@ Bio::MUST::Core::Types - Distribution-wide Moose types for Bio::MUST::Core
 
 =head1 VERSION
 
-version 0.210230
+version 0.210380
 
 =head1 SYNOPSIS
 
